# Script to generate plots with IPS results for paper:
#
#           A functionalized pyrrole coating to
#            improve fiber-matrix adhesion in
#         carbon polyphenylene sulfide composites
#
#       Van Swaaij, Helthuis, Vos, Akkerman & Grouve
#
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib
import scienceplots
from matplotlib.transforms import Bbox
import numpy as np

#
# Pandas column shorthands
# -----------------------------
d = "displacement [mm]"
σ = "stress [MPa]"
ε = "nominal strain [%]"
F = "force [N]"
S = "sample"
s = "specimen"

#
# Figure style
# -----------------------------
plt.style.use(['science', 'ieee', 'no-latex'])
font = {'size'   : 9}
matplotlib.rc('font', **font)

colors = plt.rcParams['axes.prop_cycle'].by_key()['color'][:4]
colors_bp = plt.rcParams['axes.prop_cycle'].by_key()['color'][:4]
colors_bp[0] = 'w'
fsize = np.array([90.0, 65.0])/25.4  # in inches
asize = np.array([0.15, 0.18, 0.75, 0.72])
bb = Bbox([[0, 0], [fsize[0], fsize[1]]])

#
# Plot and save figures?
# -----------------------------
plot_figs = False
save_figs = True

#
# Folders
# -----------------------------
data_folder = "../ips/"
fig_folder = "../figures/"

#
# Figure for inplane shear data
# -----------------------------
IPS_fn = ["IPS--reference_02.csv",
          "IPS--acetone_01.csv",
          "IPS--PyPh-SH_03.csv",
          "IPS--PyPh_04.csv"]
IPS = [pd.read_csv(data_folder + f, header=0) for f in IPS_fn]
labels = ["Reference", "Acetone", "PyPh-SH", "PyPh"]

# Plot data
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
for i, df in enumerate(IPS):
    df.plot(ε, σ, ax=ax, label=labels[i],
            color=[colors[i] for i in [0, 1, 2, 3]][i])
ax.set_xlabel("Nominal axial strain, %")
ax.set_ylabel("Nominal axial stress, MPa")
ax.set_xticks([], minor=True)
ax.set_xlim((0, 25))
ax.set_ylim((0, 300))
ax.legend(loc="lower right")
if save_figs: plt.savefig(fig_folder + "IPS_curves.png", dpi=720, bbox_inches=bb)
plt.show(block=False) if plot_figs else plt.close()

#
# Figure for IPS overall results
# ------------------------------
fn = "IPS--summary.csv"
IPS = pd.read_csv(data_folder + fn, header=0, encoding='utf8')

# Plot data
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
bp = IPS.boxplot(σ, by=S, ax=ax, positions=[1, 2, 3, 0],
                 grid=False, vert=True, patch_artist=True,
                 return_type='dict',
                 whiskerprops=dict(color='k', linewidth=.75),
                 flierprops=dict(color='k', markeredgecolor='k', linewidth=.75),
                 medianprops=dict(color='k', linewidth=.75))
for patch, color in zip(ax.patches, [colors_bp[i] for i in [1, 3, 2, 0]]):
    patch.set_facecolor(color)
    patch.set_edgecolor('k')
    patch.set_linewidth(0.75)
ax.set_xticks([], minor=True)
ax.set_ylim((200, 300))
ax.yaxis.grid(True)
ax.set_ylabel("In-plane shear strength, MPa")
ax.set_xlabel("")
ax.set_title("")
fig.suptitle("")
if save_figs: plt.savefig(fig_folder + "IPS_boxplot.png", dpi=720, bbox_inches=bb)
plt.show(block=False) if plot_figs else plt.close()

#
# Figure for IPS deformation analysis
# -----------------------------------
fn = "IPS--summary.csv"
IPS = pd.read_csv(data_folder + fn, header=0)

# Exclude the SEM samples from dataset
IPS.dropna(how="any", inplace=True)

# Average data
IPS = IPS.groupby("sample").agg(["mean", "std"])
ε = IPS[["eps1 [%]", "eps2 [%]", "eps3 [%]", "eps4 [%]", "eps5 [%]", "eps6 [%]"]]
γ = IPS[["gamma1 [deg]", "gamma2 [deg]", "gamma3 [deg]",
         "gamma4 [deg]", "gamma5 [deg]", "gamma6 [deg]"]]
x = np.arange(6)

# Plot shear angle
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
ref = ax.errorbar(x, γ.loc["reference"].iloc[0::2],
                 yerr=γ.loc["reference"].iloc[1::2], capsize=3, label="Reference")
ace = ax.errorbar(x, γ.loc["acetone"].iloc[0::2],
                 yerr=γ.loc["acetone"].iloc[1::2], capsize=3, label="Acetone")
pyphsh = ax.errorbar(x, γ.loc["PyPh-SH"].iloc[0::2],
                 yerr=γ.loc["PyPh-SH"].iloc[1::2], capsize=3, label="PyPh-SH")
pyph = ax.errorbar(x, γ.loc["PyPh"].iloc[0::2],
                 yerr=γ.loc["PyPh"].iloc[1::2], capsize=3, label="PyPh")
ax.set_xticks(x)
ax.set_xticklabels(["M1", "M2", "M3", "M4", "M5", "M6"])
ax.set_xticks([], minor=True)
ax.set_ylim((0, 30))
ax.set_xlim((-0.5, 5.5))
ax.set_ylabel("Nominal shear angle, °")
ax.set_xlabel("")
ax.set_title("")
handles = [ref, ace, pyphsh, pyph]
labels = [line.get_label() for line in handles]
ax.legend(handles, labels, loc="upper left")
if save_figs: plt.savefig(fig_folder + "IPS_shearangle.png", dpi=720, bbox_inches=bb)
plt.show(block=False) if plot_figs else plt.close()

# Plot transverse strain
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
ref = ax.errorbar(x, ε.loc["reference"].iloc[0::2],
                 yerr=ε.loc["reference"].iloc[1::2], capsize=3, label="Reference")
ace = ax.errorbar(x, ε.loc["acetone"].iloc[0::2],
                 yerr=ε.loc["acetone"].iloc[1::2], capsize=3, label="Acetone")
pyphsh = ax.errorbar(x, ε.loc["PyPh-SH"].iloc[0::2],
                 yerr=ε.loc["PyPh-SH"].iloc[1::2], capsize=3, label="PyPh-SH")
pyph = ax.errorbar(x, ε.loc["PyPh"].iloc[0::2],
                 yerr=ε.loc["PyPh"].iloc[1::2], capsize=3, label="PyPh")
ax.set_xticks(x)
ax.set_xticklabels(["M1", "M2", "M3", "M4", "M5", "M6"])
ax.set_xticks([], minor=True)
ax.set_ylim((-25, 0))
ax.set_xlim((-0.5, 5.5))
ax.set_ylabel("Nominal transverse strain, %")
ax.set_xlabel("")
ax.set_title("")
if save_figs: plt.savefig(fig_folder + "IPS_strain.png", dpi=720, bbox_inches=bb)
plt.show(block=False) if plot_figs else plt.close()
