# Script to generate plots with LCMS results for paper:
#
#           A functionalized pyrrole coating to
#            improve fiber-matrix adhesion in
#         carbon polyphenylene sulfide composites
#
#       Van Swaaij, Helthuis, Vos, Akkerman & Grouve
#
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.transforms import Bbox
import matplotlib
import scienceplots

#
# Figure style
# -----------------------------
plt.style.use(['science', 'ieee', 'no-latex'])
font = {'size' : 9}
matplotlib.rc('font', **font)
colors = plt.rcParams['axes.prop_cycle'].by_key()['color'][:4]

fsize = np.array([90.0, 65.0])/25.4  # in inches
asize = np.array([0.15, 0.18, 0.75, 0.72])
bb = Bbox([[0, 0], [fsize[0], fsize[1]]])

#
# Plot and save figures?
# -----------------------------
plot_figs = False
save_figs = True

#
# Folders
# -----------------------------
data_folder = "../lcms/"
fig_folder = "../figures/"

#
# UV LCMS Figures
# -----------------------------
# Read files
fns = ["UV--blanc.csv",
       "UV--PyPh-SH__5PPM.csv",
       "UV--DPS__5ppm.csv",
       "UV--DPS & PyPh-SH.csv"]
dfs = [np.loadtxt(data_folder + fn, delimiter=",",
                  skiprows=1) for fn in fns]

# Labels
labels = ["Blanc",
          "PyPh-SH 5PPM",
          "DPS 5ppm",
          "DPS & PyPh-SH"]

# Multipliers and shifts for plotting
multipliers = [0.01, 2000, 100, 100]
deltas = [10, 20, 30, 40]

# Plot graph
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
for df, label, multiplier, delta in zip(dfs, labels, multipliers, deltas):
    ax.plot(df[:, 0]/60, delta + multiplier*df[:, 1]/df[:, 1].max(),
            label=label, linewidth=0.5)

ax.set_xlim((0, 25))
ax.set_ylim((0, 120))
ax.set_yticks([])
ax.set_xlabel("Time, minutes")
ax.set_ylabel("Intensity")
ax.legend()

if save_figs: plt.savefig(fig_folder + "UV-HPLC.png", dpi=720, bbox_inches=bb)
plt.show(block=True) if plot_figs else plt.close()

# Plot zoomed graph
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
deltas = [500, 500, 500, 2]  # get other graphs out of sight
for df, label, multiplier, delta in zip(dfs, labels, multipliers, deltas):
    ax.plot(df[:, 0]/60, delta + multiplier*df[:, 1]/df[:, 1].max(),
            label=label, linewidth=0.5)
ax.set_xlim((9, 21))
ax.set_ylim((0, 15))
ax.set_yticks([])
ax.set_xlabel("Time, minutes")
ax.set_ylabel("Intensity")
ax.plot([15.92, 15.92], [3.4, 5.2], 'k', linewidth=0.5)
ax.text(16., 4.9, "15.9 min.")

if save_figs: plt.savefig(fig_folder + "UV-HPLC-zoom.png", dpi=720, bbox_inches=bb)
plt.show(block=True) if plot_figs else plt.close()


#
# MS LCMS Figures
# -----------------------------
# Read files
fns = ["MS--pre-cursor__20000ppm.csv",
       "MS--fragmented-pre-cursor__20000ppm.csv"]
dfs = [np.loadtxt(data_folder + fn, delimiter=",",
                  skiprows=1) for fn in fns]

# Figure mass spectrum pre-cursor
df = dfs[0]
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
ax.plot(df[:, 0], df[:, 1])
ax.set_xlim((0, 2200))
ax.set_ylim((0, 20E6))
ax.set_yticks([])
ax.set_xlabel("m/z")
ax.set_ylabel("Intensity")
ax.text(435, 175E5, "391.30")
if save_figs: plt.savefig(fig_folder + "MS--pre-cursor.png", dpi=720, bbox_inches=bb)
plt.show(block=True) if plot_figs else plt.close()

# Figure mass spectrum fragmented pre-cursor
df = dfs[1]
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
ax.plot(df[:, 0], df[:, 1])
ax.set_xlim((0, 450))
ax.set_ylim((0, 6E6))
ax.set_yticks([])
ax.set_xlabel("m/z")
ax.set_ylabel("Intensity")
ax.text(187, 40E5, "187.08", ha="center")
ax.text(209, 145E4, "202.10", ha="left")
ax.text(391, 438E4, "391.30", ha="center")
if save_figs: plt.savefig(fig_folder + "MS--fragmented-pre-cursor.png", dpi=720, bbox_inches=bb)
plt.show(block=True) if plot_figs else plt.close()
