# Script to generate plots with SBS results for paper:
#
#           A functionalized pyrrole coating to
#            improve fiber-matrix adhesion in
#         carbon polyphenylene sulfide composites
#
#       Van Swaaij, Helthuis, Vos, Akkerman & Grouve
#
import pandas as pd
import matplotlib.pyplot as plt
import matplotlib
import scienceplots
from matplotlib.transforms import Bbox
import numpy as np

#
# Pandas column shorthands
# -----------------------------
d = "disp. [mm]"
σ = "shear stress [MPa]"
ε = "strain [%]"
F = "force [N]"
S = "sample"
s = "specimen"

#
# Figure style
# -----------------------------
plt.style.use(['science', 'ieee', 'no-latex'])
font = {'size'   : 9}
matplotlib.rc('font', **font)

colors = plt.rcParams['axes.prop_cycle'].by_key()['color'][:4]
colors_bp = plt.rcParams['axes.prop_cycle'].by_key()['color'][:4]
colors_bp[0] = 'w'
fsize = np.array([90.0, 65.0])/25.4  # in inches
asize = np.array([0.15, 0.18, 0.75, 0.72])
bb = Bbox([[0, 0], [fsize[0], fsize[1]]])

#
# Plot and save figures?
# -----------------------------
plot_figs = False
save_figs = True

#
# Folders
# -----------------------------
data_folder = "../sbs/"
fig_folder = "../figures/"

#
# Figure for short beam shear data
# --------------------------------
SBS_fn = ["SBS--reference_09.csv",
          "SBS--acetone_13.csv",
          "SBS--PyPh-SH_03.csv"]
SBS = [pd.read_csv(data_folder + f, header=0) for f in SBS_fn]
labels = ["Reference", "Acetone", "PyPh-SH"]

# Drop data after failure
idx = [1740, 2170, 2250]  # indices from where to cut the data
for i, df in enumerate(SBS):
    df.drop(df.index[idx[i]:], inplace=True)

# Plot data
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
for i, df in enumerate(SBS):
    df.plot(d, σ, ax=ax, label=labels[i],
            color=colors[i])
ax.set_xlabel("Displacement, mm")
ax.set_ylabel("Apparent shear stress, MPa")
ax.set_xlim((0, 1.05))
ax.set_ylim((0, 80))
ax.legend(loc="lower right")
if save_figs: plt.savefig(fig_folder + "SBS_curves.png", dpi=720, bbox_inches=bb)
plt.show(block=False) if plot_figs else plt.close()

#
# Figure for SBS overall results
# ------------------------------
fn = "SBS--summary.csv"
SBS = pd.read_csv(data_folder + fn, header=0)

# Plot data
fig = plt.figure(figsize=fsize)
ax = fig.add_axes(asize)
bp = SBS.boxplot(σ, by=S, ax=ax, positions=[2, 1, 0],
                 grid=False, vert=True, patch_artist=True,
                 return_type='dict',
                 whiskerprops=dict(color='k', linewidth=.75),
                 flierprops=dict(color='k', markeredgecolor='k', linewidth=.75),
                 medianprops=dict(color='k', linewidth=.75))
for patch, color in zip(ax.patches, [colors_bp[i] for i in [2, 1, 0]]):
    patch.set_facecolor(color)
    patch.set_edgecolor('k')
    patch.set_linewidth(0.75)
ax.set_xticks([], minor=True)
ax.set_ylim((45, 75))
ax.set_ylabel("Short beam strength, MPa")
ax.set_xlabel("")
ax.yaxis.grid(True)
ax.set_title("")
fig.suptitle("")
if save_figs: plt.savefig(fig_folder + "SBS_boxplot.png", dpi=720, bbox_inches=bb)
plt.show(block=False) if plot_figs else plt.close()
